@@ -9,7 +9,8 @@ from clint.textui.core import STDOUT, STDERR
 from clint.textui.colored import green, red, blue
 
 from . import __version__
-from .core import get_links, get_pypi_packages, valid_package
+from .core import (get_urls, get_pypi_packages, valid_package,
+                   get_pypi_user_packages)
 
 
 def version():
@@ -22,6 +23,7 @@ def usage(error=False):
     options = [
         ("-h, --help", "Print this help message"),
         ("-v, --version", "Display version information"),
+        ("-e, --errors-only", "Display errors only"),
     ]
 
     puts("\nUsage:")
@@ -50,17 +52,29 @@ def process_options(options):
         if option == '-r':
             with open(arg) as f:
                 packages += get_pypi_packages(f)
+        if option == '-u':
+            packages += get_pypi_user_packages(arg)
+
     return packages
 
 
+def get_packages_from_stdin():
+    """Return packages found from standard input"""
+    input_lines = piped_in()
+    if input_lines is not None:
+        return get_pypi_packages(input_lines)
+    else:
+        return []
+
+
 def main():
 
     packages = []
     args = sys.argv[1:]
-    input_lines = None and piped_in()
 
     try:
-        opts, pkgs = getopt(args, "vhr:", ["version", "help", "requirement"])
+        opts, pkgs = getopt(args, "vhr:u:e", ["version", "help", "requirement",
+                                              "user", "errors-only"])
     except GetoptError as e:
         puts(str(e), stream=STDERR)
         usage(error=True)
@@ -68,22 +82,21 @@ def main():
 
     packages += pkgs
     packages += process_options(opts)
+    packages += get_packages_from_stdin()
+    show_only_errors = ('-e', '') in opts or ('--errors-only', '') in opts
 
-    if input_lines is not None:
-        # Add packages found from standard input
-        packages += get_pypi_packages(input_lines)
-    elif not args:
-        # Return error if no arguments given
+    if not packages:
+        # Return error if no packages found
         usage(error=True)
         sys.exit(2)
 
     for package in packages:
         if valid_package(package):
-            links = get_links(package)
-            symbol = red('\u2717') if links else green('\u2713')
-            msg = "%s %s: %s links" % (symbol, blue(package), len(links))
-            print(msg)
+            urls = get_urls(package)
+            symbol = red('\u2717') if urls else green('\u2713')
+            msg = "%s %s: %s URLs" % (symbol, blue(package), len(urls))
+            if urls or not show_only_errors:
+                print(msg)
         else:
-            symbol = red('\u2717')
-            print("%s %s: not found on PyPI" % (symbol, blue(package)),
+            print("%s %s: not found on PyPI" % (red('\u26a0'), blue(package)),
                   file=sys.stderr)
